@@ -2,20 +2,26 @@
 # PloneTestCase API
 #
 
+# $Id: ptc.py 30087 2006-09-08 10:44:04Z shh42 $
+
 from Testing.ZopeTestCase import hasProduct
 from Testing.ZopeTestCase import installProduct
 
 from Testing.ZopeTestCase import Sandboxed
 from Testing.ZopeTestCase import Functional
 
-from Testing.ZopeTestCase import utils
-from Testing.ZopeTestCase.utils import *
+from Products.PloneTestCase import utils
+from Products.PloneTestCase.utils import *
 
 from Products.PloneTestCase.setup import PLONE21
+from Products.PloneTestCase.setup import PLONE25
+from Products.PloneTestCase.setup import PLONE30
 from Products.PloneTestCase.setup import portal_name
 from Products.PloneTestCase.setup import portal_owner
 from Products.PloneTestCase.setup import default_policy
 from Products.PloneTestCase.setup import default_products
+from Products.PloneTestCase.setup import default_base_profile
+from Products.PloneTestCase.setup import default_extension_profiles
 from Products.PloneTestCase.setup import default_user
 from Products.PloneTestCase.setup import default_password
 
